@@ -1,12 +1,11 @@
 import IPython
-import logging
 import sys
 
-
+from squad_client import logging
 from squad_client.core.command import SquadClientCommand
 
 
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 
 
 class ShellCommand(SquadClientCommand):
